@@ -266,7 +266,7 @@ class SessionTests(utils.TestCase):
         # elements to make sure that all joins are appropriately
         # handled (any join of unicode and byte strings should
         # raise a UnicodeDecodeError)
-        session.post(unicode(self.TEST_URL), data=data)
+        session.post(six.text_type(self.TEST_URL), data=data)
 
         self.assertNotIn('my data', self.logger.output)
 
@@ -828,7 +828,6 @@ class SessionAuthTests(utils.TestCase):
         self.assertIn(list(response.keys())[0], output)
         self.assertIn(list(response.values())[0], output)
 
-        self.assertNotIn(self.TEST_URL, self.logger.output)
         self.assertNotIn(list(response.keys())[0], self.logger.output)
         self.assertNotIn(list(response.values())[0], self.logger.output)
 
@@ -1026,7 +1025,6 @@ class AdapterTest(utils.TestCase):
         self.assertIn(list(response.keys())[0], output)
         self.assertIn(list(response.values())[0], output)
 
-        self.assertNotIn(self.TEST_URL, self.logger.output)
         self.assertNotIn(list(response.keys())[0], self.logger.output)
         self.assertNotIn(list(response.values())[0], self.logger.output)
 
